"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = __importDefault(require("http"));
const koa_1 = __importDefault(require("koa"));
const hmr_1 = require("./middlewares/hmr");
const modules_1 = require("./middlewares/modules");
const vue_1 = require("./middlewares/vue");
const serve_1 = require("./middlewares/serve");
const historyFallback_1 = require("./middlewares/historyFallback");
const middlewares = [
    hmr_1.hmrMiddleware,
    modules_1.moduleResolverMiddleware,
    vue_1.vueMiddleware,
    historyFallback_1.historyFallbackMiddleware,
    serve_1.serveMiddleware
];
async function createServer({ port = 3000, cwd = process.cwd(), middlewares: userMiddlewares = [] } = {}) {
    const app = new koa_1.default();
    const server = http_1.default.createServer(app.callback());
    [...userMiddlewares, ...middlewares].forEach((m) => m({
        cwd,
        app,
        server
    }));
    return new Promise((resolve, reject) => {
        server.on('error', (e) => {
            if (e.code === 'EADDRINUSE') {
                console.log(`port ${port} is in use, trying another one...`);
                setTimeout(() => {
                    server.close();
                    server.listen(++port);
                }, 100);
            }
            else {
                console.error(e);
                reject(e);
            }
        });
        server.on('listening', () => {
            console.log(`Running at http://localhost:${port}`);
            resolve(server);
        });
        server.listen(port);
    });
}
exports.createServer = createServer;
