"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const resolve_from_1 = __importDefault(require("resolve-from"));
let resolved = undefined;
function resolveVue(cwd) {
    if (resolved) {
        return resolved;
    }
    let vuePath;
    let compilerPath;
    try {
        // see if user has local vue installation
        const userVuePkg = resolve_from_1.default(cwd, 'vue/package.json');
        vuePath = path_1.default.join(path_1.default.dirname(userVuePkg), 'dist/vue.runtime.esm-browser.js');
        // also resolve matching sfc compiler
        try {
            const compilerPkgPath = resolve_from_1.default(cwd, '@vue/compiler-sfc/package.json');
            const compilerPkg = require(compilerPkgPath);
            if (compilerPkg.version !== require(userVuePkg).version) {
                throw new Error();
            }
            compilerPath = path_1.default.join(path_1.default.dirname(compilerPkgPath), compilerPkg.main);
        }
        catch (e) {
            // user has local vue but has no compiler-sfc
            console.error(`[vite] Error: a local installation of \`vue\` is detected but ` +
                `no matching \`@vue/compiler-sfc\` is found. Make sure to install ` +
                `both and use the same version.`);
            compilerPath = require.resolve('@vue/compiler-sfc');
        }
    }
    catch (e) {
        // user has no local vue, use vite's dependency version
        vuePath = require.resolve('vue/dist/vue.runtime.esm-browser.js');
        compilerPath = require.resolve('@vue/compiler-sfc');
    }
    return (resolved = {
        vue: vuePath,
        compiler: compilerPath
    });
}
exports.resolveVue = resolveVue;
function resolveCompiler(cwd) {
    return require(resolveVue(cwd).compiler);
}
exports.resolveCompiler = resolveCompiler;
